#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 17-Jan-2004
#################################################################################
#
# System Who - Script part of Ethereal Realms, designed to list who is currently
#              on all realms
# Copyright (C) 2000-2004  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 29-26503 TWP RD 511
#                 Spruce Grove, Alberta
#                 T7Y 1G4
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use eRealms::Database;						# Database handler
use eRealms::Login;						# Login functionality
use eRealms::Param;						# Parameter control
use eRealms::Template;						# Template handler
use eRealms::Who;						# Who is on


#################################################################################
# Data Members
#################################################################################
my $database;							# Database handle
my $cgi;							# Common gateway interface handle
my $login;							# Login handle
my $param;							# Parameter handle
my $tmpl;							# Template handle
my $who;							# Who handle

my $url;							# URL
my $inline;							# Inline parameters

my %realm;							# Realm hash


#################################################################################
# Program Area
#################################################################################

	# Initial handles
	$cgi      = new CGI;
	$database = new eRealms::Database();

	# Connect and fetch
	$database->Connect();

	# Parameter handling
	$param = new eRealms::Param($database, $cgi);
	$param->GetParam();	

	# Fetch hash
	$database->GetHashRealm(\%realm);


	# Fetch URL
	$url = $cgi->url(-absolute=>1);

	# Retreive parameters
	$inline = $param->EmbedInline($param->Flat());

	# Document header
	print $cgi->header(-type=>'text/html',
		-refresh=>"300;URL=$url$inline");
	$database->DocumentGetAdminHeader();


	# Login and Who handle
	$login = new eRealms::Login($database, $cgi, $param);
	$tmpl  = new eRealms::Template(\%realm);
	$who   = new eRealms::Who($database, $cgi, $param);	

        # Authenthication
        if ($login->GetVerificationAdmin())
        {
		# Display title
		$tmpl->ShowMain($realm{'TagTitleWho'});

		# Display who is on
		$who->WhoSystem(\%realm);
	}

	# Document footer
	$database->DocumentGetAdminFooter();
